@@ -1,5 +1,6 @@
 from .format_options import FormatOptions
 from .indentation_utility import IndentMarker, IndentType
+from .named_types import NamedIterable, NamedMapping
 from .pretty_formatter import DefaultFormatter, IterableFormatter, MappingFormatter, PrettyFormatter
 from .text_style import (
     TextStyle,
@@ -8,21 +9,15 @@ from .text_style import (
     rm_style_modifiers,
     strlen_no_style,
 )
-from .type_formatters import (
-    CustomMultilineFormatter,
-    CustomNormalFormatter,
-    MultilineFormatter,
-    MultilineTypeFormatterFunc,
-    NormalFormatter,
-    NormalTypeFormatterFunc,
+from .type_formatter import (
     TypeFormatter,
-    multiline_formatter,
-    normal_formatter,
+    TypeFormatterFunc,
+    make_formatter,
 )
 from .type_projection import (
     TypeProjection,
     TypeProjectionFunc,
     identity_projection_func,
-    projection,
+    make_projection,
 )
 from .type_specific_callable import TypeSpecifcCallable
