@@ -15,9 +15,9 @@ class TypeProjection(TypeSpecifcCallable):
         self.__proj_func = proj_func
 
     def __call__(self, obj: Any) -> Any:
-        self._check_type(obj)
+        self._validate_type(obj)
         return self.__proj_func(obj)
 
 
-def projection(t: type, proj_func: TypeProjectionFunc) -> TypeProjection:
+def make_projection(t: type, proj_func: TypeProjectionFunc) -> TypeProjection:
     return TypeProjection(t, proj_func)
